<?php
/**
 * Comment layout
 *
 * @package skito
 */

namespace Skito\inc;

defined( 'ABSPATH' ) || die();

class Comments_layout {

    function __construct() {
        add_filter( 'comment_form_default_fields', [ $this, 'comments_form_fields' ] );
        add_filter( 'comment_form_defaults', [ $this, 'comments_form' ] );
    }

    /**
     * Markup for comments form fields
     * add_filter: comment_form_default_fields
     *
     * @param $fields
     *
     * @return array
     */
    public function comments_form_fields($fields) {
        $commenter = wp_get_current_commenter();
        $req       = get_option( 'require_name_email' );
        $aria_req  = ( $req ? " aria-required='true'" : '' );
        $consent  = empty( $commenter['comment_author_email'] ) ? '' : ' checked="checked"';
        $fields    = array(
            'author'  => '<div class="comment-form-field"><input class="comment-form-field__name" id="author" name="author" type="text" placeholder=" ' . esc_attr__( 'Name *', 'skito' ) . ' " value="' . esc_attr( $commenter['comment_author'] ) . '" ' . $aria_req . '></div>',
            'email'   => '<div class="comment-form-field"><input class="comment-form-field__email" id="email" name="email" type="email" placeholder=" ' . esc_attr__( 'Email *', 'skito' ) . ' " value="' . esc_attr( $commenter['comment_author_email'] ) . '" ' . $aria_req . '></div>',
            'url'     => '<div class="comment-form-field"><input class="comment-form-field__url" id="url" name="url" type="url" placeholder=" ' . esc_attr__( 'Website', 'skito' ) . ' " value="' . esc_attr( $commenter['comment_author_url'] ) . '"></div>',
            'cookies' => '<div class="comment-form-field"><input class="form-check-input" id="wp-comment-cookies-consent" name="wp-comment-cookies-consent" type="checkbox" value="yes"' . $consent . ' /> ' .
                '<label class="form-check-label" for="wp-comment-cookies-consent">' . __( 'Save my name, email, and website in this browser for the next time I comment', 'skito' ) . '</label></div>',
        );

        return $fields;
    }

    /**
     * Markup for comments form textarea and submit button
     * add_filter: comment_form_defaults
     *
     * @param $args
     *
     * @return mixed
     */
    public function comments_form($args) {
        $args['comment_field'] = '<div class="comment-form-field">
	    <textarea class="comment-form-field__text-area" name="comment" placeholder=" ' . esc_attr__( 'Message *', 'skito' ) . ' " aria-required="true" cols="45" rows="3"></textarea>
	    </div>';
        $args['class_submit']  = 'form-submit__button';

        return $args;
    }

}
