<?php
/**
 * Nav Walker Class
 *
 * @package skito
 */

defined( 'ABSPATH' ) || die();

if ( ! class_exists( 'Skito_Navwalker' ) ) {
    class Skito_Nav_Walker extends Walker_Nav_Menu {

        /**
         * fallback function for menu/navigation
         * if the menu is not active, then this function will fire
         *
         * @param $args
         *
         * @return string
         */
        public static function nav_fallback($args) {
            $fallback_output = '';

            if ( ! current_user_can( 'edit_theme_options' ) ) return $fallback_output;

            // Get Arguments.
            $container = $args['container'];
            $container_id = $args['container_id'];
            $container_class = $args['container_class'];
            $menu_class = $args['menu_class'];
            $menu_id = $args['menu_id'];

            if ( $container ) {
                $fallback_output .= '<' . esc_attr( $container );
                if ( $container_id ) {
                    $fallback_output .= ' id="' . esc_attr( $container_id ) . '"';
                }
                if ( $container_class ) {
                    $fallback_output .= ' class="' . esc_attr( 'skito-fallback-' . $container_class ) . '"';
                }
                $fallback_output .= '>';
            }

            $fallback_output .= '<ul';
            if ( $menu_id ) {
                $fallback_output .= ' id="' . esc_attr( $menu_id ) . '"';
            }
            if ( $menu_class ) {
                $fallback_output .= ' class="' . esc_attr( 'skito-fallback-' . $menu_class ) . '"';
            }
            $fallback_output .= '>';

            $fallback_output .= '<li class="nav-item"><a href="' . esc_url( admin_url( 'nav-menus.php' ) ) . '" class="nav-link">' . esc_html__( 'Add a menu', 'skito' ) . '</a></li>';
            $fallback_output .= '</ul>';
            if ( $container ) {
                $fallback_output .= '</' . esc_attr( $container ) . '>';
            }

            if ( array_key_exists( 'echo', $args ) && $args['echo'] ) {
                echo $fallback_output; // WPCS: XSS OK.
            } else {
                return $fallback_output;
            }
        }

    }
}
